@@ -12,17 +12,17 @@ if [ `expr $RPMVERSION` -lt 100 ]; then
 fi
 
 if [ `expr $RPMVERSION` -lt 400 ]; then
-  RPM_BA="rpm -ba -ta ./xine-ui-0.99.6.tar.gz"
-  RPM_BB="rpm -bb -ta ./xine-ui-0.99.6.tar.gz"
+  RPM_BA="rpm -ba -ta ./xine-ui-0.99.7.tar.bz2"
+  RPM_BB="rpm -bb -ta ./xine-ui-0.99.7.tar.bz2"
 elif [ `expr $RPMVERSION` -lt 420 ]; then
-  RPM_BA="rpm -ta ./xine-ui-0.99.6.tar.gz -ba"
-  RPM_BB="rpm -ta ./xine-ui-0.99.6.tar.gz -bb"
+  RPM_BA="rpm -ta ./xine-ui-0.99.7.tar.bz2 -ba"
+  RPM_BB="rpm -ta ./xine-ui-0.99.7.tar.bz2 -bb"
 else
-  RPM_BA="rpmbuild -ta ./xine-ui-0.99.6.tar.gz -ba"
-  RPM_BB="rpmbuild -ta ./xine-ui-0.99.6.tar.gz -bb"
+  RPM_BA="rpmbuild -ta ./xine-ui-0.99.7.tar.bz2 -ba"
+  RPM_BB="rpmbuild -ta ./xine-ui-0.99.7.tar.bz2 -bb"
 fi
 
-##VERSION="0.99.6"
+##VERSION=".."
 
 echo "Creating tarball..."
 rm -f config.cache && ./autogen.sh && make dist
@@ -31,7 +31,7 @@ mkdir rpms
 
 echo "*****************************************************"
 echo
-echo "building rpm for xine-ui 0.99.6"
+echo "building rpm for xine-ui 0.99.7"
 echo 
 echo "current architecture:pentium"
 echo "rpms will be copied to ./rpms directory"
@@ -42,8 +42,8 @@ export XINE_BUILD=i586-pc-linux-gnu
 
 eval $RPM_BA
 
-cp /usr/src/redhat/SRPMS/xine-ui-0.99.6-$DATE.src.rpm ./rpms/
-mv /usr/src/redhat/RPMS/i386/xine-ui-0.99.6-$DATE.i386.rpm ./rpms/xine-ui-0.99.6-$DATE.i586.rpm
-mv /usr/src/redhat/RPMS/i386/xine-ui-aa-0.99.6-$DATE.i386.rpm ./rpms/xine-ui-aa-0.99.6-$DATE.i586.rpm
+cp /usr/src/redhat/SRPMS/xine-ui-0.99.7-$DATE.src.rpm ./rpms/
+mv /usr/src/redhat/RPMS/i386/xine-ui-0.99.7-$DATE.i386.rpm ./rpms/xine-ui-0.99.7-$DATE.i586.rpm
+mv /usr/src/redhat/RPMS/i386/xine-ui-aa-0.99.7-$DATE.i386.rpm ./rpms/xine-ui-aa-0.99.7-$DATE.i586.rpm
 
 echo "Done."
