@@ -110,7 +110,7 @@ static const struct xine_speeds_s {
 #define BAR_HEIGHT 25
 
 
-static void *osd_loop(void *dummy)
+static __attribute__((noreturn)) void *osd_loop(void *dummy)
 {
 	pthread_detach(pthread_self());
 	while(1) {
@@ -142,7 +142,8 @@ static void *osd_loop(void *dummy)
 		}
 	    }
 	}
-	return NULL;
+
+	pthread_exit (NULL);
 }
 
 static const char *_osd_get_speed_sym(int speed) {
@@ -339,7 +340,7 @@ void osd_stream_infos(void) {
     uint32_t    width;
     uint32_t    vwidth, vheight, asrate;
     const char *vcodec, *acodec;
-    char        buffer[256], *p;
+    char        buffer[256];
     int         x, y;
     int         w, h, osdw;
     int         playedtime, totaltime, pos;
@@ -364,7 +365,6 @@ void osd_stream_infos(void) {
     y = x = 0;
 
     xine_osd_get_text_size(fbxine.osd.sinfo, buffer, &osdw, &h);
-    p = buffer;
     
     if(vcodec && vwidth && vheight) {
       sprintf(buffer, "%s: %dX%d", vcodec, vwidth, vheight);
