@@ -382,7 +382,8 @@ static void set_mmk(mediamark_t *mmk) {
     
     snprintf(buffer, sizeof(buffer), "xine-ui version %s", VERSION);
     
-    gGui->mmk.mrl           = strdup(_("There is no MRL."));
+    /* TRANSLATORS: only ASCII characters (skin) */
+    gGui->mmk.mrl           = strdup(pgettext("skin", "There is no MRL."));
     gGui->mmk.ident         = strdup(buffer);
     gGui->mmk.sub           = NULL;
     gGui->mmk.start         = 0;
@@ -671,6 +672,8 @@ void gui_exit (xitk_widget_t *w, void *data) {
   
   gGui->on_quit = 1;
 
+  gui_deinit();
+
   panel_deinit();
   playlist_deinit();
   mrl_browser_deinit();
@@ -694,13 +697,10 @@ void gui_exit (xitk_widget_t *w, void *data) {
   if(load_sub)
     filebrowser_end(load_sub);
 
-  gui_deinit();
-
   if(video_window_is_visible())
     video_window_set_visibility(0);
   
   tvout_deinit(gGui->tvout);
-  video_window_exit();
 
 #ifdef HAVE_XF86VIDMODE
   /* just in case a different modeline than the original one is running,
@@ -717,16 +717,9 @@ void gui_exit (xitk_widget_t *w, void *data) {
   config_update_num("gui.amp_level", gGui->mixer.amp_level);
   xine_config_save(__xineui_global_xine_instance, __xineui_global_config_file);
   
-  /* Restore old audio volume */
-  if(gGui->ao_port && (gGui->mixer.method == SOUND_CARD_MIXER))
-    xine_set_param(gGui->stream, XINE_PARAM_AUDIO_VOLUME, gGui->mixer.original_level);
-  
   xine_close(gGui->stream);
   xine_close(gGui->visual_anim.stream);
 
-  xine_event_dispose_queue(gGui->event_queue);
-  xine_event_dispose_queue(gGui->visual_anim.event_queue);
-
   /* we are going to dispose this stream, so make sure slider_loop 
    * won't use it anymore (otherwise -> segfault on exit).
    */
@@ -736,7 +729,7 @@ void gui_exit (xitk_widget_t *w, void *data) {
     xine_post_dispose(__xineui_global_xine_instance, gGui->visual_anim.post_output_element.post);
 
   xine_dispose(gGui->stream);
-  /* xine_dispose(gGui->visual_anim.stream); */
+  xine_dispose(gGui->visual_anim.stream);
 
   if(gGui->vo_port)
     xine_close_video_driver(__xineui_global_xine_instance, gGui->vo_port);
@@ -748,7 +741,7 @@ void gui_exit (xitk_widget_t *w, void *data) {
   if(gGui->ao_none)
     xine_close_audio_driver(__xineui_global_xine_instance, gGui->ao_none);
 
-  xine_exit(__xineui_global_xine_instance); 
+  video_window_exit();
 
 #ifdef HAVE_LIRC
   if(__xineui_global_lirc_enable)
@@ -867,6 +860,46 @@ void gui_stop (xitk_widget_t *w, void *data) {
   gui_display_logo();
 }
 
+void gui_close (xitk_widget_t *w, void *data) {
+
+  gGui->ignore_next = 1;
+  xine_stop (gGui->stream);
+  gGui->ignore_next = 0;
+
+  if(!(gGui->playlist.control & PLAYLIST_CONTROL_STOP_PERSIST))
+    gGui->playlist.control &= ~PLAYLIST_CONTROL_STOP;
+
+  gGui->stream_length.pos = gGui->stream_length.time = gGui->stream_length.length = 0;
+
+  mediamark_reset_played_state();
+  if(gGui->visual_anim.running) {
+    xine_stop(gGui->visual_anim.stream);
+    if(gGui->visual_anim.enabled == 2)
+      gGui->visual_anim.running = 0;
+  }
+
+  osd_hide_sinfo();
+  osd_hide_bar();
+  osd_hide_info();
+  osd_update_status();
+  panel_reset_slider ();
+  panel_check_pause();
+  panel_update_runtime_display();
+
+  if(is_playback_widgets_enabled()) {
+    if(!gGui->playlist.num) {
+      gui_set_current_mmk(NULL);
+      enable_playback_controls(0);
+    }
+    else if(gGui->playlist.num && (strcmp((mediamark_get_current_mrl()), gGui->mmk.mrl))) {
+      gui_set_current_mmk(mediamark_get_current_mmk());
+    }
+  }
+  gGui->ignore_next = 1;
+  xine_close (gGui->stream);
+  gGui->ignore_next = 0;
+}
+
 void gui_pause (xitk_widget_t *w, void *data, int state) {
   int speed = xine_get_param(gGui->stream, XINE_PARAM_SPEED);
 
@@ -1182,14 +1215,28 @@ void gui_direct_change_spu_channel(xitk_widget_t *w, void *data, int value) {
 void gui_change_spu_channel(xitk_widget_t *w, void *data) {
   int dir = (int)(intptr_t)data;
   int channel;
+  int maxchannel;
   
   channel = xine_get_param(gGui->stream, XINE_PARAM_SPU_CHANNEL);
+  maxchannel = xine_get_stream_info(gGui->stream, XINE_STREAM_INFO_MAX_SPU_CHANNEL);
+
+  if (xine_get_status(gGui->spu_stream) != XINE_STATUS_IDLE) /* if we have a slave SPU channel, take it into account */
+    maxchannel += xine_get_stream_info(gGui->spu_stream, XINE_STREAM_INFO_MAX_SPU_CHANNEL);
+
+  /* XINE_STREAM_INFO_MAX_SPU_CHANNEL actually returns the number of available spu channels, i.e. 
+   * 0 means no SPUs, 1 means 1 SPU channel, etc. */
+  --maxchannel;
 
   if(dir == GUI_NEXT)
     channel++;
   else if(dir == GUI_PREV)
     channel--;
-  
+
+  if (channel > maxchannel)
+    channel = -2; /* -2 == off, -1 == auto, 0 == 1st channel */
+  else if (channel < -2)
+    channel = maxchannel;
+
   gui_direct_change_spu_channel(w, data, channel);
 }
 
@@ -1223,7 +1270,7 @@ void gui_change_speed_playback(xitk_widget_t *w, void *data) {
   osd_update_status();
 }
 
-static void *_gui_set_current_position(void *data) {
+static __attribute__((noreturn)) void *_gui_set_current_position(void *data) {
   int  pos = (int)(intptr_t) data;
   int  update_mmk = 0;
   
@@ -1231,7 +1278,6 @@ static void *_gui_set_current_position(void *data) {
 
   if(pthread_mutex_trylock(&gGui->xe_mutex)) {
     pthread_exit(NULL);
-    return NULL;
   }
   
   if(gGui->logo_mode && (mediamark_get_current_mrl())) {
@@ -1239,7 +1285,6 @@ static void *_gui_set_current_position(void *data) {
       gui_handle_xine_error(gGui->stream, (char *)(mediamark_get_current_mrl()));
       pthread_mutex_unlock(&gGui->xe_mutex);
       pthread_exit(NULL);
-      return NULL;
     }
   }
 
@@ -1247,7 +1292,6 @@ static void *_gui_set_current_position(void *data) {
      (gGui->ignore_next == 1)) {
     pthread_mutex_unlock(&gGui->xe_mutex);
     pthread_exit(NULL);
-    return NULL;
   }
     
   if(xine_get_status(gGui->stream) != XINE_STATUS_PLAY) {
@@ -1306,10 +1350,9 @@ static void *_gui_set_current_position(void *data) {
 
   pthread_mutex_unlock(&gGui->xe_mutex);
   pthread_exit(NULL);
-  return NULL;
 }
 
-static void *_gui_seek_relative(void *data) {
+static __attribute__((noreturn)) void *_gui_seek_relative(void *data) {
   int off_sec = (int)(intptr_t)data;
   int sec, pos;
   
@@ -1321,25 +1364,21 @@ static void *_gui_seek_relative(void *data) {
 
   if(!gui_xine_get_pos_length(gGui->stream, NULL, &sec, NULL)) {
     pthread_exit(NULL);
-    return NULL;
   }
   
   if(pthread_mutex_trylock(&gGui->xe_mutex)) {
     pthread_exit(NULL);
-    return NULL;
   }
 
   if(((xine_get_stream_info(gGui->stream, XINE_STREAM_INFO_SEEKABLE)) == 0) || 
      (gGui->ignore_next == 1)) {
     pthread_mutex_unlock(&gGui->xe_mutex);
     pthread_exit(NULL);
-    return NULL;
   }
   
   if(xine_get_status(gGui->stream) != XINE_STATUS_PLAY) {
     pthread_mutex_unlock(&gGui->xe_mutex);
     pthread_exit(NULL);
-    return NULL;
   }
   
   gGui->ignore_next = 1;
@@ -1363,7 +1402,6 @@ static void *_gui_seek_relative(void *data) {
   panel_check_pause();
 
   pthread_exit(NULL);
-  return NULL;
 }
 
 void gui_set_current_position (int pos) {
@@ -2301,7 +2339,7 @@ void gui_select_sub(void) {
 void visual_anim_init(void) {
   char *buffer;
 
-  asprintf(&buffer, "%s/%s", XINE_VISDIR, "default.avi");
+  asprintf(&buffer, "%s/%s", XINE_VISDIR, "default.mpv");
   
   gGui->visual_anim.mrls = (char **) malloc(sizeof(char *) * 3);
   gGui->visual_anim.num_mrls = 0;
