@@ -185,6 +185,9 @@ typedef struct {
     int                     brightness, default_brightness;
     int                     saturation, default_saturation;
     int                     contrast, default_contrast;
+    int                     gamma, default_gamma;
+    int                     sharpness, default_sharpness;
+    int                     noise_reduction, default_noise_reduction;
   } video_settings;
 
   xine_audio_port_t        *ao_port;
@@ -317,7 +320,6 @@ typedef struct {
     int                     mute;
     int                     amp_level;
     int                     method;
-    int                     original_level;
   } mixer;
 
   xitk_register_key_t       widget_key;
@@ -375,8 +377,8 @@ typedef struct {
 
   void                     (*nongui_error_msg)(char *text);
 
-  FILE                      *stdout; /* Channel to original stdout at startup */
-                                     /* before an evtl. later redirection     */
+  FILE                      *orig_stdout; /* original stdout at startup        */
+                                          /* before an evtl. later redirection */
 } gGui_t;
 
 extern gGui_t *gGui;
@@ -453,4 +455,14 @@ void change_icon(Window window);
     XUnlockDisplay(gGui->display);                                        \
   } while(0)
 
+#ifdef HAVE_XML_PARSER_REENTRANT
+# define xml_parser_init_R(X,D,L,M) X = xml_parser_init_r ((D), (L), (M))
+# define xml_parser_build_tree_R(X,T) xml_parser_build_tree_r ((X), (T))
+# define xml_parser_finalize_R(X) xml_parser_finalize_r ((X))
+#else
+# define xml_parser_init_R(X,D,L,M) xml_parser_init ((D), (L), (M))
+# define xml_parser_build_tree_R(X,T) xml_parser_build_tree ((T))
+# define xml_parser_finalize_R(X) do {} while (0)
+#endif
+
 #endif
