@@ -39,6 +39,7 @@
 #include <sys/wait.h>
 #include <time.h>
 #include <stdlib.h>
+#include <pthread.h>
 
 /* input_pvr functionality needs this */
 #define XINE_ENABLE_EXPERIMENTAL_FEATURES
@@ -46,8 +47,6 @@
 #include "common.h"
 #include "oxine/oxine.h"
 
-#define STEP_SIZE 256
-
 /*
  * global variables
  */
@@ -108,6 +107,11 @@ static const char *const shortcut_style[] = {
   NULL
 };
 
+static volatile int reject_events = 1;
+
+pthread_mutex_t event_mutex;
+
+
 int hidden_file_cb(int action, int value) {
   xine_cfg_entry_t  cfg_entry;
   int               retval = 0;
@@ -364,6 +368,16 @@ static char *pts2str(int64_t pts) {
  */
 void gui_execute_action_id(action_id_t action) {
   xine_event_t   xine_event;
+
+  if(reject_events)
+    return;
+
+  pthread_mutex_lock(&event_mutex);
+
+  if (reject_events) {
+    pthread_mutex_unlock(&event_mutex);
+    return;
+  }
   
   if(action & ACTID_IS_INPUT_EVENT) {
 
@@ -408,8 +422,10 @@ void gui_execute_action_id(action_id_t action) {
     }
 
     /* check if osd menu like this event */
-    if( oxine_action_event(action & ~ACTID_IS_INPUT_EVENT) )
+    if( oxine_action_event(action & ~ACTID_IS_INPUT_EVENT) ) {
+      pthread_mutex_unlock(&event_mutex);
       return;
+    }
     
     /* events for advanced input plugins. */
     xine_event.type        = action & ~ACTID_IS_INPUT_EVENT;
@@ -419,6 +435,7 @@ void gui_execute_action_id(action_id_t action) {
     gettimeofday(&xine_event.tv, NULL);
     
     xine_event_send(gGui->stream, &xine_event);
+    pthread_mutex_unlock(&event_mutex);
     return;
   }
 
@@ -534,7 +551,12 @@ void gui_execute_action_id(action_id_t action) {
     break;
 
   case ACTID_TOGGLE_FULLSCREEN:
-    gui_set_fullscreen_mode(NULL, NULL);
+    if (gGui->numeric.set) {
+      int fullscreen = video_window_get_fullscreen_mode() & FULLSCR_MODE;
+      if ((gGui->numeric.arg && !fullscreen) || (!gGui->numeric.arg && fullscreen))
+        gui_set_fullscreen_mode(NULL, NULL);
+    } else
+      gui_set_fullscreen_mode(NULL, NULL);
     break;
 
 #ifdef HAVE_XINERAMA
@@ -570,6 +592,10 @@ void gui_execute_action_id(action_id_t action) {
     gui_stop(NULL, NULL);
     break;
 
+  case ACTID_CLOSE:
+    gui_close(NULL, NULL);
+    break;
+
   case ACTID_EVENT_SENDER:
     gui_event_sender_show(NULL, NULL);
     break;
@@ -966,63 +992,64 @@ void gui_execute_action_id(action_id_t action) {
     break;
 
   case ACTID_HUECONTROLp:
-    if(gGui->video_settings.hue <= (65535 - STEP_SIZE)) {
-      config_update_num("gui.vo_hue", gGui->video_settings.hue + STEP_SIZE);
-      control_set_image_prop(XINE_PARAM_VO_HUE, gGui->video_settings.hue);
-      osd_draw_bar(_("Hue"), 0, 65535, gGui->video_settings.hue, OSD_BAR_STEPPER);
-    }
+    control_inc_image_prop(XINE_PARAM_VO_HUE);
     break;
   case ACTID_HUECONTROLm:
-    if(gGui->video_settings.hue >= STEP_SIZE) {
-      config_update_num("gui.vo_hue", gGui->video_settings.hue - STEP_SIZE);
-      control_set_image_prop(XINE_PARAM_VO_HUE, gGui->video_settings.hue);
-      osd_draw_bar(_("Hue"), 0, 65535, gGui->video_settings.hue, OSD_BAR_STEPPER);
-    }
+    control_dec_image_prop(XINE_PARAM_VO_HUE);
     break;
 
   case ACTID_SATURATIONCONTROLp:
-    if(gGui->video_settings.saturation <= (65535 - STEP_SIZE)) {
-      config_update_num("gui.vo_saturation", gGui->video_settings.saturation + STEP_SIZE);
-      control_set_image_prop(XINE_PARAM_VO_SATURATION, gGui->video_settings.saturation);
-      osd_draw_bar(_("Saturation"), 0, 65535, gGui->video_settings.saturation, OSD_BAR_STEPPER);
-    }
+    control_inc_image_prop(XINE_PARAM_VO_SATURATION);
     break;
   case ACTID_SATURATIONCONTROLm:
-    if(gGui->video_settings.saturation >= STEP_SIZE) {
-      config_update_num("gui.vo_saturation", gGui->video_settings.saturation - STEP_SIZE);
-      control_set_image_prop(XINE_PARAM_VO_SATURATION, gGui->video_settings.saturation);
-      osd_draw_bar(_("Saturation"), 0, 65535, gGui->video_settings.saturation, OSD_BAR_STEPPER);
-    }
+    control_dec_image_prop(XINE_PARAM_VO_SATURATION);
     break;
 
   case ACTID_BRIGHTNESSCONTROLp:
-    if(gGui->video_settings.brightness <= (65535 - STEP_SIZE)) {
-      config_update_num("gui.vo_brightness", gGui->video_settings.brightness + STEP_SIZE);
-      control_set_image_prop(XINE_PARAM_VO_BRIGHTNESS, gGui->video_settings.brightness);
-      osd_draw_bar(_("Brightness"), 0, 65535, gGui->video_settings.brightness, OSD_BAR_STEPPER);
-    }
+    control_inc_image_prop(XINE_PARAM_VO_BRIGHTNESS);
     break;
   case ACTID_BRIGHTNESSCONTROLm:
-    if(gGui->video_settings.brightness >= STEP_SIZE) {
-      config_update_num("gui.vo_brightness", gGui->video_settings.brightness - STEP_SIZE);
-      control_set_image_prop(XINE_PARAM_VO_BRIGHTNESS, gGui->video_settings.brightness);
-      osd_draw_bar(_("Brightness"), 0, 65535, gGui->video_settings.brightness, OSD_BAR_STEPPER);
-    }
+    control_dec_image_prop(XINE_PARAM_VO_BRIGHTNESS);
     break;
 
   case ACTID_CONTRASTCONTROLp:
-    if(gGui->video_settings.contrast <= (65535 - STEP_SIZE)) {
-      config_update_num("gui.vo_contrast", gGui->video_settings.contrast + STEP_SIZE);
-      control_set_image_prop(XINE_PARAM_VO_CONTRAST, gGui->video_settings.contrast);
-      osd_draw_bar(_("Contrast"), 0, 65535, gGui->video_settings.contrast, OSD_BAR_STEPPER);
-    }
+    control_inc_image_prop(XINE_PARAM_VO_CONTRAST);
     break;
   case ACTID_CONTRASTCONTROLm:
-    if(gGui->video_settings.contrast >= STEP_SIZE) {
-      config_update_num("gui.vo_contrast", gGui->video_settings.contrast - STEP_SIZE);
-      control_set_image_prop(XINE_PARAM_VO_CONTRAST, gGui->video_settings.contrast);
-      osd_draw_bar(_("Contrast"), 0, 65535, gGui->video_settings.contrast, OSD_BAR_STEPPER);
-    }
+    control_dec_image_prop(XINE_PARAM_VO_CONTRAST);
+    break;
+
+  case ACTID_GAMMACONTROLp:
+#ifdef XINE_PARAM_VO_GAMMA
+    control_inc_image_prop(XINE_PARAM_VO_GAMMA);
+#endif
+    break;
+  case ACTID_GAMMACONTROLm:
+#ifdef XINE_PARAM_VO_GAMMA
+    control_dec_image_prop(XINE_PARAM_VO_GAMMA);
+#endif
+    break;
+
+  case ACTID_SHARPNESSCONTROLp:
+#ifdef XINE_PARAM_VO_SHARPNESS
+    control_inc_image_prop(XINE_PARAM_VO_SHARPNESS);
+#endif
+    break;
+  case ACTID_SHARPNESSCONTROLm:
+#ifdef XINE_PARAM_VO_SHARPNESS
+    control_dec_image_prop(XINE_PARAM_VO_SHARPNESS);
+#endif
+    break;
+
+  case ACTID_NOISEREDUCTIONCONTROLp:
+#ifdef XINE_PARAM_VO_NOISE_REDUCTION
+    control_inc_image_prop(XINE_PARAM_VO_NOISE_REDUCTION);
+#endif
+    break;
+  case ACTID_NOISEREDUCTIONCONTROLm:
+#ifdef XINE_PARAM_VO_NOISE_REDUCTION
+    control_dec_image_prop(XINE_PARAM_VO_NOISE_REDUCTION);
+#endif
     break;
 
   case ACTID_VPP:
@@ -1213,6 +1240,7 @@ void gui_execute_action_id(action_id_t action) {
   gGui->numeric.arg = 0;
   gGui->alphanum.set = 0;
   gGui->alphanum.arg = "";
+  pthread_mutex_unlock(&event_mutex);
 }
 
 /*
@@ -1476,6 +1504,10 @@ static void gui_find_visual (Visual **visual_return, int *depth_return) {
 }
 
 void gui_deinit(void) {
+  pthread_mutex_lock(&event_mutex);
+  reject_events = 1;
+  pthread_mutex_unlock(&event_mutex);
+
   xitk_unregister_event_handler(&gGui->widget_key);
 }
 
@@ -1486,6 +1518,11 @@ void gui_init (int nfiles, char *filenames[], window_attributes_t *window_attrib
   int    i;
   char  *server;
   char  *video_display_name;
+  pthread_mutexattr_t attr;
+
+  pthread_mutexattr_init(&attr);
+  pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_RECURSIVE);
+  pthread_mutex_init(&event_mutex, &attr);
 
   /*
    * init playlist
@@ -1837,6 +1874,7 @@ void gui_init (int nfiles, char *filenames[], window_attributes_t *window_attrib
   gui_set_current_mmk(mediamark_get_current_mmk());
 
   panel_init();
+  reject_events = 0;
 }
 
 void gui_init_imlib (Visual *vis) {
@@ -1883,7 +1921,7 @@ void gui_init_imlib (Visual *vis) {
   
   gGui->icon = XCreateBitmapFromData (gGui->display, 
 				      gGui->imlib_data->x.root,
-				      icon_datas, 40, 40);
+				      (const char *)icon_datas, 40, 40);
 }
 
 /*
