@@ -32,6 +32,9 @@
 #    else
 #        define N_(String) (String)
 #    endif
+#    define XITK_GETTEXT_SEP "\004"
+#    define pgettext(Ctx, String) gettext(Ctx XITK_GETTEXT_SEP String) == Ctx XITK_GETTEXT_SEP String ? String : gettext(Ctx XITK_GETTEXT_SEP String)
+
 #else
 /* Stubs that do something close enough.  */
 #    define textdomain(String) (String)
@@ -41,6 +44,7 @@
 #    define bindtextdomain(Domain,Directory) (Domain)
 #    define _(String) (String)
 #    define N_(String) (String)
+#    define pgettext(Ctx, String) (String)
 #endif
 
 #endif
