@@ -147,7 +147,7 @@ static char *_read_file(const char *filename, int *size) {
     return NULL;
   }
 
-  if((fd = open(filename, O_RDONLY)) == -1) {
+  if((fd = xine_open_cloexec(filename, O_RDONLY)) == -1) {
     fprintf(stderr, "%s(): open(%s) failed: %s.\n", __XINE_FUNCTION__, filename, strerror(errno));
     return NULL;
   }
@@ -575,7 +575,7 @@ static mediamark_t **guess_m3u_playlist(playlist_t *playlist, const char *filena
 		      title = strdup(ptitle);
 		  }
 		}
-		else {
+		else if (ln[0] != '#') {
 		  char  buffer[_PATH_MAX + _NAME_MAX + 2];
 		  const char *entry;
 		  
@@ -796,7 +796,7 @@ static mediamark_t **guess_toxine_playlist(playlist_t *playlist, const char *fil
 	playlist->data = tox_content;
 	
 	if(playlist_split_data(playlist)) {
-	  char    buffer[23768], path[_PATH_MAX + _NAME_MAX + 2];
+	  char    buffer[32768], path[_PATH_MAX + _NAME_MAX + 2];
 	  char   *p, *pp, *origin;
 	  int     start = 0;
 	  int     linen = 0;
@@ -976,8 +976,9 @@ static mediamark_t **guess_toxine_playlist(playlist_t *playlist, const char *fil
 		  }
 		  
 		  if(*pp != '\0') {
-		    *p = *pp;
-		    p++;
+		    /* buffer full? don't copy */
+		    if (p - buffer < sizeof (buffer) - 1)
+		      *p++ = *pp;
 		    pp++;
 		  }
 		}
@@ -1425,7 +1426,7 @@ static mediamark_t **xml_noatun_playlist(playlist_t *playlist, const char *filen
 
 #ifdef DEBUG_SMIL
 static int offset = 0;
-#define palign {int i; for(i = 0; i < offset; i++) { printf(" "); } } while(0)
+#define palign do { int i; for(i = 0; i < offset; i++) { printf(" "); } } while(0)
 #endif
 
 typedef struct smil_node_s smil_node_t;
@@ -2473,8 +2474,8 @@ static mediamark_t **guess_xml_based_playlist(playlist_t *playlist, const char *
 	NULL
       };
 
-      xml_parser_init(xml_content, size, XML_PARSER_CASE_INSENSITIVE);
-      if((result = xml_parser_build_tree(&xml_tree)) != XML_PARSER_OK)
+      xml_parser_init_R(xml_parser_t *xml, xml_content, size, XML_PARSER_CASE_INSENSITIVE);
+      if((result = xml_parser_build_tree_R(xml, &xml_tree)) != XML_PARSER_OK)
 	goto __failure;
       
       top_xml_tree = xml_tree;
@@ -2488,6 +2489,7 @@ static mediamark_t **guess_xml_based_playlist(playlist_t *playlist, const char *
       xml_parser_free_tree(top_xml_tree);
     __failure:
       
+      xml_parser_finalize_R(xml);
       free(xml_content);
     }
   }
