@@ -739,7 +739,7 @@ void playlist_scan_input(xitk_widget_t *w, void *ip) {
       
       if(!strcasecmp(autoplay_plugins[i], xitk_labelbutton_get_label(w))) {
 	int                num_mrls = 0;
-	char             **autoplay_mrls = xine_get_autoplay_mrls(__xineui_global_xine_instance, autoplay_plugins[i], &num_mrls);
+	const char * const *autoplay_mrls = xine_get_autoplay_mrls(__xineui_global_xine_instance, autoplay_plugins[i], &num_mrls);
 	xine_stream_t      *stream;
 	
 	if(autoplay_mrls) {
@@ -1234,7 +1234,8 @@ void playlist_editor(void) {
     (playlist->playlist = xitk_browser_create(playlist->widget_list, gGui->skin_config, &br)));
 
   lbl.skin_element_name = "AutoPlayLbl";
-  lbl.label             = _("Scan for:");
+  /* TRANSLATORS: only ASCII characters (skin) */
+  lbl.label             = pgettext("skin", "Scan for:");
   lbl.callback          = NULL;
   xitk_list_append_content ((XITK_WIDGET_LIST_LIST(playlist->widget_list)),
 			    xitk_label_create (playlist->widget_list, gGui->skin_config, &lbl));
