@@ -32,6 +32,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
+#include <fcntl.h>
 #include <strings.h>
 #include <sys/types.h>
 #include <sys/select.h>
@@ -129,7 +130,7 @@ uint8_t get_boolean(int session, ctrl_commands_t command) {
 }
 #endif
 
-static void *ctrlsocket_func(void *data) {
+static __attribute__((noreturn)) void *ctrlsocket_func(void *data) {
   fd_set                set;
   struct timeval        tv;
   serv_header_packet_t *shdr;
@@ -156,7 +157,11 @@ static void *ctrlsocket_func(void *data) {
     if(((select(ctrl_fd + 1, &set, NULL, NULL, &tv)) <= 0) || 
        ((fd = accept(ctrl_fd, &saddr.sa, &len)) == -1))
       continue;
-    
+
+    if (fcntl(fd, F_SETFD, FD_CLOEXEC) < 0) {
+        fprintf(stderr, "ctrlsocket_func(): Failed to make socket uninheritable (%s)\n", strerror(errno));
+    }
+
     shdr = (serv_header_packet_t *) calloc(1, sizeof(serv_header_packet_t));
 
     (void) read(fd, &(shdr->hdr), sizeof(ctrl_header_packet_t));
@@ -443,7 +448,8 @@ int init_session(void) {
   int                  retval = 0;
   int                  i;
   
-  if((ctrl_fd = socket(AF_UNIX, SOCK_STREAM, 0)) != -1) {
+  if((ctrl_fd = xine_socket_cloexec(AF_UNIX, SOCK_STREAM, 0)) != -1) {
+
     for(i = 0;; i++)	{
       saddr.un.sun_family = AF_UNIX;
       
@@ -497,7 +503,7 @@ int session_handle_subopt(char *suboptarg, int *session) {
   int          playlist_first, playlist_last, playlist_clear, playlist_next, playlist_prev, playlist_stop_cont;
   int          audio_next, audio_prev, spu_next, spu_prev;
   int          volume, amp, loop, speed_status, time_status;
-  int          fullscreen, s, c;
+  int          s, c;
   uint32_t     state;
   char        *optstr;
   char       **mrls          = NULL;
@@ -517,7 +523,6 @@ int session_handle_subopt(char *suboptarg, int *session) {
   };
   
   playlist_first = playlist_last = playlist_clear = playlist_next = playlist_prev = playlist_stop_cont = 0;
-  fullscreen     = 0;
   audio_next     = audio_prev = spu_next = spu_prev = 0;
   volume = amp   = -1;
   state          = 0;
