@@ -90,8 +90,8 @@ static slx_entry_t **skins_get_slx_entries(char *url) {
   if((network_download(url, &download))) {
     int entries_slx = 0;
     
-    xml_parser_init(download.buf, download.size, XML_PARSER_CASE_INSENSITIVE);
-    if((result = xml_parser_build_tree(&xml_tree)) != XML_PARSER_OK)
+    xml_parser_init_R(xml_parser_t *xml, download.buf, download.size, XML_PARSER_CASE_INSENSITIVE);
+    if((result = xml_parser_build_tree_R(xml, &xml_tree)) != XML_PARSER_OK)
       goto __failure;
     
     if(!strcasecmp(xml_tree->name, "SLX")) {
@@ -205,6 +205,7 @@ static slx_entry_t **skins_get_slx_entries(char *url) {
     }
     
     xml_parser_free_tree(xml_tree);
+    xml_parser_finalize_R(xml);
 
     if(entries_slx)
       slxs[entries_slx] = NULL;
@@ -574,7 +575,7 @@ void download_skin(char *url) {
   slx_entry_t         **slxs;
   xitk_window_t        *xwin;
   xitk_pixmap_t        *bg;
-  int                   x, y, w, h, width, height;
+  int                   w, width, height;
   xitk_widget_t        *widget;
 
   if(skdloader.running)
@@ -587,10 +588,7 @@ void download_skin(char *url) {
   }
 
   w = 300;
-  h = 50;
   XLockDisplay(gGui->display);
-  x = (((DisplayWidth(gGui->display, gGui->screen))) >> 1) - (w >> 1);
-  y = (((DisplayHeight(gGui->display, gGui->screen))) >> 1) - (h >> 1);
   XUnlockDisplay(gGui->display);
   
   xwin = xitk_window_dialog_button_free_with_width(gGui->imlib_data, _("Be patient..."),
