@@ -52,9 +52,10 @@ static const xitk_mrlbrowser_filter_t __mrl_filters[] = {
   { "*.mp3"               , "mp3"          }, /* mp3 */
   { "*.asf, *.wmv"        , "asf,wmv"      }, /* asf */
   { "*.cpk, *.cak, *.film", "cpk,cak,film" }, /* film */
-  { "*.ogg"               , "ogg"          }, /* ogg */
+  { "*.ogg, *.ogm, *.ogv" , "ogg"          }, /* ogg */
   { "*.vdr"               , "vdr"          }, /* pes */
   { "*.mov, *.mp4, *.qt"  , "mov,mp4,qt"   }, /* QT */
+  { "*.m4a, *.m4b"        , "mp4 audio"    }, /* QT (audio) */
   { "*.roq"               , "roq"          }, /* roq */
   { "*.m2t, *.ts, *.trp"  , "m2t,ts,trp"   }, /* ts */
   { "*.rmvb"              , "rmvb"         }, /* rmvb */
@@ -975,7 +976,6 @@ xitk_widget_t *xitk_mrlbrowser_create(xitk_widget_list_t *wl,
   XWMHints                   *wm_hint;
   XClassHint                 *xclasshint;
   XColor                      black, dummy;
-  int                         screen;
   xitk_widget_t              *mywidget;
   mrlbrowser_private_data_t  *private_data;
   xitk_labelbutton_widget_t   lb;
@@ -1038,7 +1038,6 @@ xitk_widget_t *xitk_mrlbrowser_create(xitk_widget_list_t *wl,
   hint.flags  = PPosition | PSize;
 
   XLOCK(mb->imlibdata->x.disp);
-  screen = DefaultScreen(mb->imlibdata->x.disp);
 
   XAllocNamedColor(mb->imlibdata->x.disp, 
 		   Imlib_get_colormap(mb->imlibdata),
