@@ -264,11 +264,13 @@ xitk_window_t *xitk_window_create_window(ImlibData *im, int x, int y, int width,
   hint.width           = width;
   hint.base_width      = width;
   hint.min_width       = width;
+  hint.max_width       = width;
   hint.height          = height;
   hint.base_height     = height;
   hint.min_height      = height;
+  hint.max_height      = height;
   hint.win_gravity     = NorthWestGravity;
-  hint.flags           = PWinGravity | PBaseSize | PMinSize | USSize | USPosition;
+  hint.flags           = PWinGravity | PBaseSize | PMinSize | PMaxSize | USSize | USPosition;
   
   XLOCK(im->x.disp);
   XAllocNamedColor(im->x.disp, Imlib_get_colormap(im), "black", &black, &dummy);
@@ -668,12 +670,11 @@ static void _window_handle_event(XEvent *event, void *data) {
     XKeyEvent  mykeyevent;
     KeySym     mykey;
     char       kbuf[256];
-    int        len;
     
     mykeyevent = event->xkey;
     
     XLOCK(wd->imlibdata->x.disp);
-    len = XLookupString(&mykeyevent, kbuf, sizeof(kbuf), &mykey, NULL);
+    XLookupString(&mykeyevent, kbuf, sizeof(kbuf), &mykey, NULL);
     XUNLOCK(wd->imlibdata->x.disp);
     
     switch (mykey) {
