@@ -63,30 +63,32 @@ extern char **environ;
 #ifdef TRACE_LOCKS
 static int ml = 0;
 #define MUTLOCK()                                                             \
-  {                                                                           \
+  do {                                                                        \
     int i;                                                                    \
     ml++;                                                                     \
     for(i=0; i<ml; i++) printf(".");                                          \
     printf("LOCK\n");                                                         \
     pthread_mutex_lock(&gXitk->mutex);                                        \
-  }
+  } while (0)
 
 #define MUTUNLOCK()                                                           \
-  {                                                                           \
+  do {                                                                           \
     int i;                                                                    \
     for(i=0; i<ml; i++) printf(".");                                          \
     printf("UNLOCK\n");                                                       \
     ml--;                                                                     \
     pthread_mutex_unlock(&gXitk->mutex);                                      \
-  }
+  } while (0)
 
 #else
-#define MUTLOCK()   { pthread_mutex_lock(&gXitk->mutex); }
-#define MUTUNLOCK() { pthread_mutex_unlock(&gXitk->mutex); }
+#define MUTLOCK()   pthread_mutex_lock(&gXitk->mutex)
+#define MUTUNLOCK() pthread_mutex_unlock(&gXitk->mutex)
 #endif
 
-#define FXLOCK(_fx) { pthread_mutex_lock(&_fx->mutex); }
-#define FXUNLOCK(_fx) { pthread_mutex_unlock(&_fx->mutex); }
+#define FXLOCK(_fx)       __gfx_lock(_fx)
+#define FXTRYLOCK(_fx)    __gfx_trylock(_fx)
+#define FXUNLOCK(_fx)     __gfx_unlock(_fx)
+#define FXSELFLOCKED(_fx) __gfx_selflocked(_fx)
 
 
 typedef struct {
@@ -120,8 +122,38 @@ typedef struct {
 
   pthread_mutex_t             mutex;
   int                         destroy;
+  pthread_t                   owning_thread;
 } __gfx_t;
 
+static int __gfx_lock(__gfx_t *fx)
+{
+  int retval = pthread_mutex_lock(&fx->mutex);
+  if (0 == retval)
+    fx->owning_thread = pthread_self();
+
+  return retval;
+}
+
+static int __gfx_trylock(__gfx_t *fx)
+{
+  int retval = pthread_mutex_trylock(&fx->mutex);
+  if (0 == retval)
+    fx->owning_thread = pthread_self();
+
+  return retval;
+}
+
+static int __gfx_unlock(__gfx_t *fx)
+{
+  fx->owning_thread = (pthread_t)0;
+  return pthread_mutex_unlock(&fx->mutex);
+}
+
+static int __gfx_selflocked(__gfx_t *fx)
+{
+  return pthread_equal(fx->owning_thread, pthread_self());
+}
+
 typedef struct {
   Display                    *display;
   XColor                      black;
@@ -174,6 +206,12 @@ static Atom XA_WM_WINDOW_TYPE_MENU = None;
 static Atom XA_WM_WINDOW_TYPE_UTILITY = None;
 static Atom XA_WM_WINDOW_TYPE_SPLASH = None;
 static Atom XA_WM_WINDOW_TYPE_DIALOG = None;
+static Atom XA_WM_WINDOW_TYPE_DROPDOWN_MENU = None;
+static Atom XA_WM_WINDOW_TYPE_POPUP_MENU = None;
+static Atom XA_WM_WINDOW_TYPE_TOOLTIP = None;
+static Atom XA_WM_WINDOW_TYPE_NOTIFICATION = None;
+static Atom XA_WM_WINDOW_TYPE_COMBO = None;
+static Atom XA_WM_WINDOW_TYPE_DND = None;
 static Atom XA_WM_WINDOW_TYPE_NORMAL = None;
 
 void widget_stop(void);
@@ -248,6 +286,10 @@ void xitk_usec_sleep(unsigned long usec) {
 #endif
 }
 
+static int _x_ignoring_error_handler(Display *display, XErrorEvent *xevent) {
+  return 0;
+}
+
 static int _x_error_handler(Display *display, XErrorEvent *xevent) {
   char buffer[2048];
   
@@ -578,15 +620,21 @@ static uint32_t xitk_check_wm(Display *display) {
     XA_NET_WM_STATE_ABOVE      = XInternAtom(display, "_NET_WM_STATE_ABOVE", False);
     XA_NET_WM_STATE_FULLSCREEN = XInternAtom(display, "_NET_WM_STATE_FULLSCREEN", False);
 
-    XA_WM_WINDOW_TYPE          = XInternAtom(display, "_NET_WM_WINDOW_TYPE", False);
-    XA_WM_WINDOW_TYPE_DESKTOP  = XInternAtom(display, "_NET_WM_WINDOW_TYPE_DESKTOP", False);
-    XA_WM_WINDOW_TYPE_DOCK     = XInternAtom(display, "_NET_WM_WINDOW_TYPE_DOCK", False);
-    XA_WM_WINDOW_TYPE_TOOLBAR  = XInternAtom(display, "_NET_WM_WINDOW_TYPE_TOOLBAR", False);
-    XA_WM_WINDOW_TYPE_MENU     = XInternAtom(display, "_NET_WM_WINDOW_TYPE_MENU", False);
-    XA_WM_WINDOW_TYPE_UTILITY  = XInternAtom(display, "_NET_WM_WINDOW_TYPE_UTILITY", False);
-    XA_WM_WINDOW_TYPE_SPLASH   = XInternAtom(display, "_NET_WM_WINDOW_TYPE_SPLASH", False);
-    XA_WM_WINDOW_TYPE_DIALOG   = XInternAtom(display, "_NET_WM_WINDOW_TYPE_DIALOG", False);
-    XA_WM_WINDOW_TYPE_NORMAL   = XInternAtom(display, "_NET_WM_WINDOW_TYPE_NORMAL", False);
+    XA_WM_WINDOW_TYPE               = XInternAtom(display, "_NET_WM_WINDOW_TYPE", False);
+    XA_WM_WINDOW_TYPE_DESKTOP       = XInternAtom(display, "_NET_WM_WINDOW_TYPE_DESKTOP", False);
+    XA_WM_WINDOW_TYPE_DOCK          = XInternAtom(display, "_NET_WM_WINDOW_TYPE_DOCK", False);
+    XA_WM_WINDOW_TYPE_TOOLBAR       = XInternAtom(display, "_NET_WM_WINDOW_TYPE_TOOLBAR", False);
+    XA_WM_WINDOW_TYPE_MENU          = XInternAtom(display, "_NET_WM_WINDOW_TYPE_MENU", False);
+    XA_WM_WINDOW_TYPE_UTILITY       = XInternAtom(display, "_NET_WM_WINDOW_TYPE_UTILITY", False);
+    XA_WM_WINDOW_TYPE_SPLASH        = XInternAtom(display, "_NET_WM_WINDOW_TYPE_SPLASH", False);
+    XA_WM_WINDOW_TYPE_DIALOG        = XInternAtom(display, "_NET_WM_WINDOW_TYPE_DIALOG", False);
+    XA_WM_WINDOW_TYPE_DROPDOWN_MENU = XInternAtom(display, "_NET_WM_WINDOW_TYPE_DROPDOWN_MENU", False);
+    XA_WM_WINDOW_TYPE_POPUP_MENU    = XInternAtom(display, "_NET_WM_WINDOW_TYPE_POPUP_MENU", False);
+    XA_WM_WINDOW_TYPE_TOOLTIP       = XInternAtom(display, "_NET_WM_WINDOW_TYPE_TOOLTIP", False);
+    XA_WM_WINDOW_TYPE_NOTIFICATION  = XInternAtom(display, "_NET_WM_WINDOW_TYPE_NOTIFICATION", False);
+    XA_WM_WINDOW_TYPE_COMBO         = XInternAtom(display, "_NET_WM_WINDOW_TYPE_COMBO", False);
+    XA_WM_WINDOW_TYPE_DND           = XInternAtom(display, "_NET_WM_WINDOW_TYPE_DND", False);
+    XA_WM_WINDOW_TYPE_NORMAL        = XInternAtom(display, "_NET_WM_WINDOW_TYPE_NORMAL", False);
   }
   
   switch(type & WM_TYPE_COMP_MASK) {
@@ -898,6 +946,24 @@ static void _set_wm_window_type(Window window, xitk_wm_window_type_t type, int v
     case WINDOW_TYPE_DIALOG:
       atom = &XA_WM_WINDOW_TYPE_DIALOG;
       break;
+    case WINDOW_TYPE_DROPDOWN_MENU:
+      atom = &XA_WM_WINDOW_TYPE_DROPDOWN_MENU;
+      break;
+    case WINDOW_TYPE_POPUP_MENU:
+      atom = &XA_WM_WINDOW_TYPE_POPUP_MENU;
+      break;
+    case WINDOW_TYPE_TOOLTIP:
+      atom = &XA_WM_WINDOW_TYPE_TOOLTIP;
+      break;
+    case WINDOW_TYPE_NOTIFICATION:
+      atom = &XA_WM_WINDOW_TYPE_NOTIFICATION;
+      break;
+    case WINDOW_TYPE_COMBO:
+      atom = &XA_WM_WINDOW_TYPE_COMBO;
+      break;
+    case WINDOW_TYPE_DND:
+      atom = &XA_WM_WINDOW_TYPE_DND;
+      break;
     case WINDOW_TYPE_NORMAL:
       atom = &XA_WM_WINDOW_TYPE_NORMAL;
       break;
@@ -1012,6 +1078,7 @@ xitk_register_key_t xitk_register_event_handler(char *name, Window window,
   fx->height    = 0;
   fx->user_data = user_data;
   pthread_mutex_init(&fx->mutex, NULL);
+  fx->owning_thread = (pthread_t)0;
   
   if(window != None) {
     XWindowAttributes wattr;
@@ -1166,7 +1233,12 @@ void xitk_unregister_event_handler(xitk_register_key_t *key) {
   
   while(fx) {
 
-    if(pthread_mutex_trylock(&fx->mutex)) {
+    if(FXTRYLOCK(fx)) {
+      if (!FXSELFLOCKED(fx)) {
+        FXLOCK(fx);
+        goto locked;
+      }
+
       if(fx->key == *key) {
 	*key        = 0; 
 	fx->destroy = 1;
@@ -1175,6 +1247,7 @@ void xitk_unregister_event_handler(xitk_register_key_t *key) {
       }
     }
     else {
+locked:
       if(fx->key == *key) {
 	*key = 0; 
 	
@@ -1230,8 +1303,12 @@ int xitk_get_window_info(xitk_register_key_t key, window_info_t *winf) {
   while(fx) {
     int  already_locked = 0;
     
-    if(pthread_mutex_trylock(&fx->mutex))
-      already_locked = 1;
+    if(FXTRYLOCK(fx)) {
+      if (FXSELFLOCKED(fx))
+        already_locked = 1;
+      else
+        FXLOCK(fx);
+    }
 
     if((fx->key == key) && (fx->window != None)) {
       Window c;
@@ -1270,12 +1347,21 @@ int xitk_get_window_info(xitk_register_key_t key, window_info_t *winf) {
   return 0;
 }
 
+static void xitk_xevent_notify_impl(XEvent *event);
+
+void xitk_xevent_notify(XEvent *event) {
+  /* protect walking through gfx list */
+  MUTLOCK();
+  xitk_xevent_notify_impl(event);
+  MUTUNLOCK();
+}
+
 /*
  * Here events are handled. All widget are locally
  * handled, then if a event handler callback was passed
  * at register time, it will be called.
  */
-void xitk_xevent_notify(XEvent *event) {
+void xitk_xevent_notify_impl(XEvent *event) {
   __gfx_t  *fx, *fxd;
      
   if(!(fx = (__gfx_t *) xitk_list_first_content(gXitk->gfx)))
@@ -1329,7 +1415,6 @@ void xitk_xevent_notify(XEvent *event) {
 	  XKeyEvent      mykeyevent;
 	  KeySym         mykey;
 	  char           kbuf[256];
-	  int            len;
 	  int            modifier;
 	  int            handled = 0;
 	  xitk_widget_t *w = NULL;
@@ -1339,7 +1424,7 @@ void xitk_xevent_notify(XEvent *event) {
 	  xitk_get_key_modifier(event, &modifier);
 
 	  XLOCK(gXitk->display);
-	  len = XLookupString(&mykeyevent, kbuf, sizeof(kbuf), &mykey, NULL);
+	  XLookupString(&mykeyevent, kbuf, sizeof(kbuf), &mykey, NULL);
 	  XUNLOCK(gXitk->display);
 
 	  xitk_tips_hide_tips();
@@ -1553,8 +1638,7 @@ void xitk_xevent_notify(XEvent *event) {
 	  
 	case MotionNotify: {
 	  XWindowAttributes wattr;
-	  Status            err;
-	  
+
 	  XLOCK(gXitk->display);
 	  while(XCheckMaskEvent(gXitk->display, ButtonMotionMask, event) == True);
 	  XUNLOCK(gXitk->display);
@@ -1585,7 +1669,7 @@ void xitk_xevent_notify(XEvent *event) {
 
 	    XMoveWindow(gXitk->display, fx->window,
 			fx->new_pos.x, fx->new_pos.y);
-	    err = XGetWindowAttributes(gXitk->display, fx->window, &wattr);
+	    XGetWindowAttributes(gXitk->display, fx->window, &wattr);
 
 	    XUNLOCK(gXitk->display);
 
@@ -1802,6 +1886,7 @@ void xitk_xevent_notify(XEvent *event) {
  */
 void xitk_init(Display *display, XColor black, int verbosity) {
   char buffer[256];
+  pthread_mutexattr_t attr;
   
   xitk_pid = getppid();
 
@@ -1833,7 +1918,9 @@ void xitk_init(Display *display, XColor black, int verbosity) {
 
   memset(&gXitk->keypress, 0, sizeof(gXitk->keypress));
 
-  pthread_mutex_init (&gXitk->mutex, NULL);
+  pthread_mutexattr_init(&attr);
+  pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_RECURSIVE);
+  pthread_mutex_init (&gXitk->mutex, &attr);
   
   snprintf(buffer, sizeof(buffer), "-[ xiTK version %d.%d.%d ", XITK_MAJOR_VERSION, XITK_MINOR_VERSION, XITK_SUB_VERSION);
   
@@ -2073,8 +2160,15 @@ void xitk_stop(void) {
   xitk_cursors_deinit(gXitk->display);
   gXitk->running = 0;
 
-  if(gXitk->parent.window != None)
+  if(gXitk->parent.window != None) {
+    int (*previous_error_handler)(Display *, XErrorEvent *);
+    XSync(gXitk->display, False);
+    /* don't care about BadWindow when the focussed window is gone already */
+    previous_error_handler = XSetErrorHandler(_x_ignoring_error_handler);
     XSetInputFocus(gXitk->display, gXitk->parent.window, gXitk->parent.focus, CurrentTime);
+    XSync(gXitk->display, False);
+    XSetErrorHandler(previous_error_handler);
+  }
 }
  
 char *xitk_get_system_font(void) {
