@@ -183,11 +183,11 @@ typedef struct {
 #define MWM_HINTS_DECORATIONS       (1L << 1)
 #define PROP_MWM_HINTS_ELEMENTS     5
 typedef struct _mwmhints {
-  uint32_t                          flags;
-  uint32_t                          functions;
-  uint32_t                          decorations;
-  int32_t                           input_mode;
-  uint32_t                          status;
+  unsigned long                     flags;
+  unsigned long                     functions;
+  unsigned long                     decorations;
+  long                              input_mode;
+  unsigned long                     status;
 } MWMHints;
 
 typedef struct {
@@ -323,6 +323,12 @@ typedef enum {
   WINDOW_TYPE_UTILITY,
   WINDOW_TYPE_SPLASH,
   WINDOW_TYPE_DIALOG,
+  WINDOW_TYPE_DROPDOWN_MENU,
+  WINDOW_TYPE_POPUP_MENU,
+  WINDOW_TYPE_TOOLTIP,
+  WINDOW_TYPE_NOTIFICATION,
+  WINDOW_TYPE_COMBO,
+  WINDOW_TYPE_DND,
   WINDOW_TYPE_NORMAL
 } xitk_wm_window_type_t;
 
